GeometricMeanRank
=================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: GeometricMeanRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~GeometricMeanRank.increasing
      ~GeometricMeanRank.name
      ~GeometricMeanRank.synonyms
      ~GeometricMeanRank.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~GeometricMeanRank.__call__
      ~GeometricMeanRank.expected_value

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: name
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: expected_value
